Enum DataClass Copy item path Source #[repr(i32)]
pub enum DataClass {
Unknown = 0,
Scalar = 1,
Tensor = 2,
BlobSequence = 3,
}Unknown data class, used (implicitly) for legacy data. Will not be
processed by data ingestion pipelines.
Scalar time series. Each Value for the corresponding tag must have
tensor set to a rank-0 tensor of type DT_FLOAT (float32).
Tensor time series. Each Value for the corresponding tag must have
tensor set. The tensor value is arbitrary, but should be small to
accommodate direct storage in database backends: an upper bound of a few
kilobytes is a reasonable rule of thumb.
Blob sequence time series. Each Value for the corresponding tag must
have tensor set to a rank-1 tensor of bytestring dtype.
Returns true if value is a variant of DataClass.
👎 Deprecated: Use the TryFrom<i32> implementation instead
Converts an i32 to a DataClass, or None if value is not a valid variant.
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable
(if the ProtoBuf definition does not change) and safe for programmatic use.
Creates an enum from field names used in the ProtoBuf definition.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Returns the “default value” for a type.
Read more Converts to this type from the input type.
Compares and returns the maximum of two values.
Read more Compares and returns the minimum of two values.
Read more Restrict a value to a certain interval.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
This method returns an ordering between
self and
other values if one exists.
Read more Tests less than (for
self and
other) and is used by the
< operator.
Read more Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more Tests greater than (for
self and
other) and is used by the
>
operator.
Read more Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more The type returned in the event of a conversion error.
Performs the conversion.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.